api.users.v1.test_helpers.subject package — Argus-Toolbelt 1.0 documentation

# api.users.v1.test_helpers.subject package

## Submodules

## api.users.v1.test_helpers.subject.find_subjects module

`api.users.v1.test_helpers.subject.find_subjects.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/search, respond with HTTP 403

`api.users.v1.test_helpers.subject.find_subjects.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/search, respond with HTTP 404

`api.users.v1.test_helpers.subject.find_subjects.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/search, respond with HTTP 200

`api.users.v1.test_helpers.subject.find_subjects.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/search, respond with HTTP 401

## api.users.v1.test_helpers.subject.get_subject_by_id module

`api.users.v1.test_helpers.subject.get_subject_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 403

`api.users.v1.test_helpers.subject.get_subject_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 404

`api.users.v1.test_helpers.subject.get_subject_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 200

`api.users.v1.test_helpers.subject.get_subject_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 401

## api.users.v1.test_helpers.subject.get_subject_by_name module

`api.users.v1.test_helpers.subject.get_subject_by_name.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 403

`api.users.v1.test_helpers.subject.get_subject_by_name.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 404

`api.users.v1.test_helpers.subject.get_subject_by_name.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 200

`api.users.v1.test_helpers.subject.get_subject_by_name.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject/w+, respond with HTTP 401

## api.users.v1.test_helpers.subject.list_subjects module

`api.users.v1.test_helpers.subject.list_subjects.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject, respond with HTTP 403

`api.users.v1.test_helpers.subject.list_subjects.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject, respond with HTTP 404

`api.users.v1.test_helpers.subject.list_subjects.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject, respond with HTTP 200

`api.users.v1.test_helpers.subject.list_subjects.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/users/v1/subject, respond with HTTP 401

## Module contents